@@ -17,10 +17,10 @@ impl SaveCacheItem{
 
 
     pub(crate) fn clone_dir_info(&self) -> SaveDirInfo{ self.info.clone() }
-    pub fn save_dir(&self) -> &Path{ self.info.save_dir() }
-    pub fn current_src(&self) -> &CurrentSrc{ self.info.current_src() }
-    pub fn hash(&self) -> u128{ self.info.hash() }
-    pub fn clone_src_root(&self) -> RootObject{ self.info.clone_src_root() }
-    pub fn queued(&self) -> usize{ self.queued.load(Ordering::Relaxed) }
+    pub(crate) fn save_dir(&self) -> &Path{ self.info.save_dir() }
+    pub(crate) fn current_src(&self) -> &CurrentSrc{ self.info.current_src() }
+    pub(crate) fn hash(&self) -> u128{ self.info.hash() }
+    pub(crate) fn clone_src_root(&self) -> RootObject{ self.info.clone_src_root() }
+    pub(crate) fn queued(&self) -> usize{ self.queued.load(Ordering::Relaxed) }
     pub(crate) fn queued_atomic(&self) -> &AtomicUsize{ &self.queued }
 }
\ No newline at end of file
